@@ -5,7 +5,7 @@ function(evalNet.o){
 adj.m <- evalNet.o$adj;
 netsignedge.m <- evalNet.o$netsign;
 sign.v <- evalNet.o$s;
-netcons<- evalNet.o$netcons
+netcons.v <- evalNet.o$netcons
 ######################################
 
 ## first need to define inverse map
@@ -26,11 +26,17 @@ for(e in pruneE.idx){
   pradj.m[rowe,cole] <- 0;
   pradj.m[cole,rowe] <- 0;
 }
-diag(pradj.m)<-0
 
 
-(sum(pradj.m))/sum(adj.m)->  consist.score
+score <- sum(pradj.m)/sum(adj.m);
 
-return(list(pradj=pradj.m,sign=sign.v,consist.score=consist.score,netcons=netcons));
+library(igraph);
+gr.o <- graph.adjacency(pradj.m,mode="undirected");
+clust.o <-clusters(gr.o);
+maxc.idx <- which(clust.o$membership==(which.max(clust.o$csize)-1));
+pradjMC.m <- pradj.m[maxc.idx,maxc.idx];
+signMC.v <- sign.v[maxc.idx];
+
+ return(list(pradj=pradj.m,sign=sign.v,score=score,netcons=netcons.v,pradjMC=pradjMC.m,signMC=signMC.v));
 }
 
